==> create-fly-1.21.8-6.0.8-1-sources.jar: com/zurrtum/create/client/mixin/LivingEntityRendererMixin.java <==
package com.zurrtum.create.client.mixin;

import com.zurrtum.create.AllSynchedDatas;
import com.zurrtum.create.catnip.data.Iterate;
import com.zurrtum.create.client.AllPartialModels;
import com.zurrtum.create.client.content.equipment.armor.BacktankFeatureRenderer;
import com.zurrtum.create.client.content.equipment.armor.CardboardArmorHandlerClient;
import com.zurrtum.create.client.content.equipment.hats.HatFeatureRenderer;
import com.zurrtum.create.client.content.equipment.hats.HatState;
import com.zurrtum.create.client.flywheel.lib.model.baked.PartialModel;
import com.zurrtum.create.content.contraptions.actors.seat.SeatEntity;
import com.zurrtum.create.content.logistics.stockTicker.StockTickerBlock;
import com.zurrtum.create.content.trains.entity.CarriageContraption;
import com.zurrtum.create.content.trains.entity.CarriageContraptionEntity;
import net.minecraft.class_10034;
import net.minecraft.class_10042;
import net.minecraft.class_10055;
import net.minecraft.class_1007;
import net.minecraft.class_1297;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1453;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_3883;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_5617;
import net.minecraft.class_572;
import net.minecraft.class_583;
import net.minecraft.class_877;
import net.minecraft.class_922;
import net.minecraft.class_943;
import net.minecraft.client.render.entity.*;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.List;

@Mixin(class_922.class)
public class LivingEntityRendererMixin<T extends class_1309, S extends class_10042, M extends class_583<? super S>> {
    @Shadow
    @Final
    protected List<class_3887<S, M>> features;

    @SuppressWarnings("unchecked")
    @Inject(method = "<init>", at = @At("TAIL"))
    private void addFeature(class_5617.class_5618 ctx, M model, float shadowRadius, CallbackInfo ci) {
        if (model instanceof class_572) {
            BacktankFeatureRenderer<?, ?> renderer = new BacktankFeatureRenderer<>((class_3883<? extends class_10034, class_572<? super class_10034>>) this);
            features.add((class_3887<S, M>) renderer);
        }
        class_922<T, S, M> renderer = (class_922<T, S, M>) (Object) this;
        if (!(renderer instanceof class_943 || renderer instanceof class_877)) {
            features.add(new HatFeatureRenderer<>(renderer));
        }
    }

    @Inject(method = "updateRenderState(Lnet/minecraft/entity/LivingEntity;Lnet/minecraft/client/render/entity/state/LivingEntityRenderState;F)V", at = @At("TAIL"))
    private void addHat(T entity, S renderState, float f, CallbackInfo ci) {
        if (features.stream().noneMatch(feature -> feature instanceof HatFeatureRenderer)) {
            return;
        }
        HatState state = (HatState) renderState;
        PartialModel hat = null;
        if (entity.method_5765()) {
            class_1799 stack = entity.method_6118(class_1304.field_6169);
            class_1297 vehicle = entity.method_5854();
            if (stack.method_7960() && vehicle instanceof CarriageContraptionEntity cce && (cce.hasSchedule() || entity instanceof class_1657) && cce.getContraption() instanceof CarriageContraption cc) {
                class_2338 seatOf = cc.getSeatOf(entity.method_5667());
                if (seatOf != null && cc.conductorSeats.get(seatOf) != null) {
                    hat = AllPartialModels.TRAIN_HAT;
                    state.create$updateHatInfo(entity);
                }
            }
            if (hat == null && vehicle instanceof SeatEntity) {
                class_1937 level = entity.method_37908();
                class_2338 pos = entity.method_24515();
                boolean find = false;
                Find:
                for (class_2350 d : Iterate.horizontalDirections) {
                    for (int y : Iterate.zeroAndOne) {
                        if (!(level.method_8320(pos.method_10093(d).method_10086(y)).method_26204() instanceof StockTickerBlock))
                            continue;
                        if (find) {
                            find = false;
                            break Find;
                        }
                        find = true;
                    }
                }
                if (find) {
                    hat = AllPartialModels.LOGISTICS_HAT;
                    state.create$updateHatInfo(entity);
                }
            }
        } else if (entity instanceof class_1453 parrot && entity.method_6118(class_1304.field_6169)
            .method_7960() && AllSynchedDatas.PARROT_TRAIN_HAT.get(parrot)) {
            hat = AllPartialModels.TRAIN_HAT;
            state.create$updateHatInfo(entity);
        }
        state.create$setHat(hat);
    }

    @SuppressWarnings("unchecked")
    @Inject(method = "render(Lnet/minecraft/client/render/entity/state/LivingEntityRenderState;Lnet/minecraft/client/util/math/MatrixStack;Lnet/minecraft/client/render/VertexConsumerProvider;I)V", at = @At("HEAD"), cancellable = true)
    private void render(S state, class_4587 matrixStack, class_4597 vertexConsumerProvider, int light, CallbackInfo ci) {
        if ((class_922<T, S, M>) (Object) this instanceof class_1007 renderer && CardboardArmorHandlerClient.playerRendersAsBoxWhenSneaking(renderer,
            (class_10055) state,
            matrixStack,
            vertexConsumerProvider,
            light
        )) {
            ci.cancel();
        }
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/client/mixin/LivingEntityRendererMixin.java <==
package com.zurrtum.create.client.mixin;

import com.zurrtum.create.AllSynchedDatas;
import com.zurrtum.create.catnip.data.Iterate;
import com.zurrtum.create.client.AllPartialModels;
import com.zurrtum.create.client.content.equipment.armor.BacktankFeatureRenderer;
import com.zurrtum.create.client.content.equipment.armor.CardboardArmorHandlerClient;
import com.zurrtum.create.client.content.equipment.hats.HatFeatureRenderer;
import com.zurrtum.create.client.content.equipment.hats.HatState;
import com.zurrtum.create.client.flywheel.lib.model.baked.PartialModel;
import com.zurrtum.create.content.contraptions.actors.seat.SeatEntity;
import com.zurrtum.create.content.logistics.stockTicker.StockTickerBlock;
import com.zurrtum.create.content.trains.entity.CarriageContraption;
import com.zurrtum.create.content.trains.entity.CarriageContraptionEntity;
import net.minecraft.class_10034;
import net.minecraft.class_10042;
import net.minecraft.class_10055;
import net.minecraft.class_1007;
import net.minecraft.class_11659;
import net.minecraft.class_12075;
import net.minecraft.class_1297;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1453;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_3883;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_5617;
import net.minecraft.class_572;
import net.minecraft.class_583;
import net.minecraft.class_877;
import net.minecraft.class_922;
import net.minecraft.class_943;
import net.minecraft.client.renderer.entity.*;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.List;

@Mixin(class_922.class)
public class LivingEntityRendererMixin<T extends class_1309, S extends class_10042, M extends class_583<? super S>> {
    @Shadow
    @Final
    protected List<class_3887<S, M>> layers;

    @SuppressWarnings("unchecked")
    @Inject(method = "<init>", at = @At("TAIL"))
    private void addFeature(class_5617.class_5618 ctx, M model, float shadowRadius, CallbackInfo ci) {
        if (model instanceof class_572) {
            BacktankFeatureRenderer<?, ?> renderer = new BacktankFeatureRenderer<>((class_3883<? extends class_10034, class_572<? super class_10034>>) this);
            layers.add((class_3887<S, M>) renderer);
        }
        class_922<T, S, M> renderer = (class_922<T, S, M>) (Object) this;
        if (!(renderer instanceof class_943 || renderer instanceof class_877)) {
            layers.add(new HatFeatureRenderer<>(renderer));
        }
    }

    @Inject(method = "extractRenderState(Lnet/minecraft/world/entity/LivingEntity;Lnet/minecraft/client/renderer/entity/state/LivingEntityRenderState;F)V", at = @At("TAIL"))
    private void addHat(T entity, S renderState, float f, CallbackInfo ci) {
        if (layers.stream().noneMatch(feature -> feature instanceof HatFeatureRenderer)) {
            return;
        }
        HatState state = (HatState) renderState;
        PartialModel hat = null;
        if (entity.method_5765()) {
            class_1799 stack = entity.method_6118(class_1304.field_6169);
            class_1297 vehicle = entity.method_5854();
            if (stack.method_7960() && vehicle instanceof CarriageContraptionEntity cce && (cce.hasSchedule() || entity instanceof class_1657) && cce.getContraption() instanceof CarriageContraption cc) {
                class_2338 seatOf = cc.getSeatOf(entity.method_5667());
                if (seatOf != null && cc.conductorSeats.get(seatOf) != null) {
                    hat = AllPartialModels.TRAIN_HAT;
                    state.create$updateHatInfo(entity);
                }
            }
            if (hat == null && vehicle instanceof SeatEntity) {
                class_1937 level = entity.method_73183();
                class_2338 pos = entity.method_24515();
                boolean find = false;
                Find:
                for (class_2350 d : Iterate.horizontalDirections) {
                    for (int y : Iterate.zeroAndOne) {
                        if (!(level.method_8320(pos.method_10093(d).method_10086(y)).method_26204() instanceof StockTickerBlock))
                            continue;
                        if (find) {
                            find = false;
                            break Find;
                        }
                        find = true;
                    }
                }
                if (find) {
                    hat = AllPartialModels.LOGISTICS_HAT;
                    state.create$updateHatInfo(entity);
                }
            }
        } else if (entity instanceof class_1453 parrot && entity.method_6118(class_1304.field_6169).method_7960() && AllSynchedDatas.PARROT_TRAIN_HAT.get(
            parrot)) {
            hat = AllPartialModels.TRAIN_HAT;
            state.create$updateHatInfo(entity);
        }
        state.create$setHat(hat);
    }

    @SuppressWarnings("unchecked")
    @Inject(method = "submit(Lnet/minecraft/client/renderer/entity/state/LivingEntityRenderState;Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/SubmitNodeCollector;Lnet/minecraft/client/renderer/state/CameraRenderState;)V", at = @At("HEAD"), cancellable = true)
    private void render(S state, class_4587 matrixStack, class_11659 queue, class_12075 cameraRenderState, CallbackInfo ci) {
        if ((class_922<T, S, M>) (Object) this instanceof class_1007<?> renderer && CardboardArmorHandlerClient.playerRendersAsBoxWhenSneaking(renderer,
            (class_10055) state,
            matrixStack,
            queue
        )) {
            ci.cancel();
        }
    }
}
